@@ -72,6 +72,8 @@ class TestJail(unittest.TestCase):
         cache.settings.CACHE_BACKEND = "libmemcached"
         cache._was_closed = False
         old_cache_parse_backend = getattr(cache, "parse_backend_uri", None)
+        if old_cache_parse_backend: # checks to make sure attr exists
+            delattr(cache, 'parse_backend_uri')
 
         def monkeypatched_cache_close(*args, **kwargs):
             cache._was_closed = True
@@ -175,7 +177,7 @@ class TestTaskWrapper(unittest.TestCase):
     def test_execute_ack(self):
         tid = gen_unique_id()
         tw = TaskWrapper("cu.mytask", tid, mytask, [4], {"f": "x"},
-                        on_acknowledge=on_ack)
+                        on_ack=on_ack)
         self.assertEquals(tw.execute(), 256)
         meta = TaskMeta.objects.get(task_id=tid)
         self.assertTrue(scratch["ACK"])
