@@ -50,8 +50,12 @@ class AMQPListener(object):
     def start(self):
         """Start processing AMQP messages."""
         task_consumer = self.reset_connection()
+
+        self.logger.debug("AMQPListener: Starting message consumer...")
         it = task_consumer.iterconsume(limit=None)
 
+        self.logger.debug("AMQPListener: Ready to accept tasks!")
+
         while True:
             it.next()
 
@@ -71,13 +75,17 @@ class AMQPListener(object):
             task = TaskWrapper.from_message(message, message_data,
                                             logger=self.logger)
         except NotRegistered, exc:
-            self.logger.info("Unknown task ignored: %s" % (exc))
+            self.logger.error("Unknown task ignored: %s" % (exc))
             return
 
         eta = message_data.get("eta")
         if eta:
+            self.logger.info("Got task from broker: %s[%s] eta:[%s]" % (
+                    task.task_name, task.task_id, eta))
             self.hold_queue.put((task, eta))
         else:
+            self.logger.info("Got task from broker: %s[%s]" % (
+                    task.task_name, task.task_id))
             self.bucket_queue.put(task)
 
     def close_connection(self):
@@ -86,6 +94,8 @@ class AMQPListener(object):
             self.task_consumer.close()
             self.task_consumer = None
         if self.amqp_connection:
+            self.logger.debug(
+                    "AMQPListener: Closing connection to the broker...")
             self.amqp_connection.close()
             self.amqp_connection = None
 
@@ -96,6 +106,8 @@ class AMQPListener(object):
         Resets the task consumer in :attr:`task_consumer`.
 
         """
+        self.logger.debug(
+                "AMQPListener: Re-establishing connection to the broker...")
         self.close_connection()
         self.amqp_connection = DjangoAMQPConnection()
         self.task_consumer = TaskConsumer(connection=self.amqp_connection)
@@ -180,6 +192,8 @@ class WorkController(object):
         self.bucket_queue = Queue()
         self.hold_queue = Queue()
 
+        self.logger.debug("Instantiating thread components...")
+
         # Threads+Pool
         self.periodic_work_controller = PeriodicWorkController(
                                                     self.bucket_queue,
@@ -202,7 +216,10 @@ class WorkController(object):
         self._state = "RUN"
 
         try:
-            [component.start() for component in self.components]
+            for component in self.components:
+                self.logger.debug("Starting thread %s..." % \
+                        component.__class__.__name__)
+                component.start()
         finally:
             self.stop()
 
@@ -221,10 +238,7 @@ class WorkController(object):
 
     def process_task(self, task):
         """Process task by sending it to the pool of workers."""
-        self.logger.info("Got task from broker: %s[%s]" % (
-                task.task_name, task.task_id))
         task.execute_using_pool(self.pool, self.loglevel, self.logfile)
-        self.logger.debug("Task %s has been executed." % task)
 
     def stop(self):
         """Gracefully shutdown the worker server."""
