@@ -6,11 +6,12 @@ Worker Controller Threads
 from celery.backends import default_periodic_status_backend
 from Queue import Empty as QueueEmpty
 from datetime import datetime
+from multiprocessing import get_logger
 import threading
 import time
 
 
-class InfinityThread(threading.Thread):
+class BackgroundThread(threading.Thread):
     """Thread running an infinite loop which for every iteration
     calls its :meth:`on_iteration` method.
 
@@ -21,7 +22,7 @@ class InfinityThread(threading.Thread):
     is_infinite = True
 
     def __init__(self):
-        super(InfinityThread, self).__init__()
+        super(BackgroundThread, self).__init__()
         self._shutdown = threading.Event()
         self._stopped = threading.Event()
         self.setDaemon(True)
@@ -32,25 +33,37 @@ class InfinityThread(threading.Thread):
         To start the thread use :meth:`start` instead.
 
         """
+        self.on_start()
+
         while self.is_infinite:
             if self._shutdown.isSet():
                 break
             self.on_iteration()
         self._stopped.set() # indicate that we are stopped
 
+    def on_start(self):
+        """This handler is run at thread start, just before the infinite
+        loop."""
+        pass
+
     def on_iteration(self):
         """This is the method called for every iteration and must be
-        implemented by every subclass of :class:`InfinityThread`."""
+        implemented by every subclass of :class:`BackgroundThread`."""
         raise NotImplementedError(
                 "InfiniteThreads must implement on_iteration")
 
+    def on_stop(self):
+        """This handler is run when the thread is shutdown."""
+        pass
+
     def stop(self):
         """Gracefully shutdown the thread."""
+        self.on_stop()
         self._shutdown.set()
         self._stopped.wait() # block until this thread is done
 
 
-class Mediator(InfinityThread):
+class Mediator(BackgroundThread):
     """Thread continuously sending tasks in the queue to the pool.
 
     .. attribute:: bucket_queue
@@ -70,16 +83,21 @@ class Mediator(InfinityThread):
         self.callback = callback
 
     def on_iteration(self):
+        logger = get_logger()
         try:
+            logger.debug("Mediator: Trying to get message from bucket_queue")
             # This blocks until there's a message in the queue.
             task = self.bucket_queue.get(timeout=1)
         except QueueEmpty:
+            logger.debug("Mediator: Bucket queue is empty.")
             pass
         else:
+            logger.debug("Mediator: Running callback for task: %s[%s]" % (
+                task.task_name, task.task_id))
             self.callback(task)
 
 
-class PeriodicWorkController(InfinityThread):
+class PeriodicWorkController(BackgroundThread):
     """A thread that continuously checks if there are
     :class:`celery.task.PeriodicTask` tasks waiting for execution,
     and executes them. It also finds tasks in the hold queue that is
@@ -95,22 +113,45 @@ class PeriodicWorkController(InfinityThread):
         self.hold_queue = hold_queue
         self.bucket_queue = bucket_queue
 
+    def on_start(self):
+        """Do backend-specific periodic task initialization."""
+        default_periodic_status_backend.init_periodic_tasks()
+
     def on_iteration(self):
+        logger = get_logger()
+        logger.debug("PeriodicWorkController: Running periodic tasks...")
         self.run_periodic_tasks()
+        logger.debug("PeriodicWorkController: Processing hold queue...")
         self.process_hold_queue()
+        logger.debug("PeriodicWorkController: Going to sleep...")
         time.sleep(1)
 
     def run_periodic_tasks(self):
-        default_periodic_status_backend.run_periodic_tasks()
+        logger = get_logger()
+        applied = default_periodic_status_backend.run_periodic_tasks()
+        for task, task_id in applied:
+            logger.debug(
+                "PeriodicWorkController: Periodic task %s applied (%s)" % (
+                    task.name, task_id))
 
     def process_hold_queue(self):
         """Finds paused tasks that are ready for execution and move
         them to the :attr:`bucket_queue`."""
+        logger = get_logger()
         try:
+            logger.debug(
+                "PeriodicWorkController: Getting next task from hold queue..")
             task, eta = self.hold_queue.get_nowait()
         except QueueEmpty:
+            logger.debug("PeriodicWorkController: Hold queue is empty")
             return
         if datetime.now() >= eta:
+            logger.debug(
+                "PeriodicWorkController: Time to run %s[%s] (%s)..." % (
+                    task.task_name, task.task_id, eta))
             self.bucket_queue.put(task)
         else:
+            logger.debug(
+                "PeriodicWorkController: ETA not ready for %s[%s] (%s)..." % (
+                    task.task_name, task.task_id, eta))
             self.hold_queue.put((task, eta))
