@@ -85,8 +85,9 @@ def jail(task_id, task_name, func, args, kwargs):
     except (SystemExit, KeyboardInterrupt):
         raise
     except Exception, exc:
-        default_backend.mark_as_failure(task_id, exc)
-        retval = ExceptionInfo(sys.exc_info())
+        stored_exc = default_backend.mark_as_failure(task_id, exc)
+        type_, _, tb = sys.exc_info()
+        retval = ExceptionInfo((type_, stored_exc, tb))
     else:
         if not ignore_result:
             default_backend.mark_as_done(task_id, result)
@@ -145,14 +146,14 @@ class TaskWrapper(object):
     fail_email_body = TASK_FAIL_EMAIL_BODY
 
     def __init__(self, task_name, task_id, task_func, args, kwargs,
-            on_acknowledge=None, **opts):
+            on_ack=None, **opts):
         self.task_name = task_name
         self.task_id = task_id
         self.task_func = task_func
         self.args = args
         self.kwargs = kwargs
         self.logger = kwargs.get("logger")
-        self.on_acknowledge = on_acknowledge
+        self.on_ack = on_ack
         for opt in ("success_msg", "fail_msg", "fail_email_subject",
                 "fail_email_body"):
             setattr(self, opt, opts.get(opt, getattr(self, opt, None)))
@@ -189,7 +190,7 @@ class TaskWrapper(object):
             raise NotRegistered(task_name)
         task_func = tasks[task_name]
         return cls(task_name, task_id, task_func, args, kwargs,
-                    on_acknowledge=message.ack, logger=logger)
+                    on_ack=message.ack, logger=logger)
 
     def extend_with_default_kwargs(self, loglevel, logfile):
         """Extend the tasks keyword arguments with standard task arguments.
@@ -214,8 +215,9 @@ class TaskWrapper(object):
 
         """
         task_func_kwargs = self.extend_with_default_kwargs(loglevel, logfile)
-        if self.on_acknowledge:
-            self.on_acknowledge()
+        # acknowledge task as being processed.
+        if self.on_ack:
+            self.on_ack()
         return jail(self.task_id, self.task_name, self.task_func,
                     self.args, task_func_kwargs)
 
@@ -272,5 +274,5 @@ class TaskWrapper(object):
                      self.args, task_func_kwargs]
         return pool.apply_async(jail, args=jail_args,
                 callbacks=[self.on_success], errbacks=[self.on_failure],
-                on_acknowledge=self.on_acknowledge,
+                on_ack=self.on_ack,
                 meta={"task_id": self.task_id, "task_name": self.task_name})
